@@ -7,7 +7,7 @@ package A1z::HTML5::Template;
 
 sub NAME { my $self = shift; my $NAME; $NAME = "Fast and Easy Web Apps"; return $NAME; }
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 
 
@@ -1036,9 +1036,9 @@ sub html_setTitle
 	my %in;
 	
 	%in = (
-		a => qq{},
-		b => qq{},
-		c => qq{},
+		ta => qq{},
+		tb => qq{},
+		tc => qq{},
 		@_,
 	);
 
@@ -1046,9 +1046,9 @@ sub html_setTitle
 <!-- Begin
 	function setTitle() 
 	{
-		var a = "$in{a}";
-		var b = "$in{b}";
-		var c = "$in{c}";
+		var a = "$in{ta}";
+		var b = "$in{tb}";
+		var c = "$in{tc}";
 		var t = new Date();
 		s = t.getSeconds();
 		if (s == 10) { document.title = a;}
@@ -1142,7 +1142,7 @@ sub head
 		-jqueryui 	=> html_jqueryui_css, 
 		-htmlshim	=> html_shim_respond, 
 		-humanejs  => html_humanejs_css, 
-		-title 		=> "$ENV{SERVER_NAME}" || "", 
+		-title 		=> "A1z.us", 
 		-cssLinks => "https://code.jquery.com/ui/1.11.4/themes/ui-lightness/jquery-ui.css,https://blueimp.github.io/Gallery/css/blueimp-gallery.min.css,https://www.a1z.us/A1z/HTML5/Template.css", 
 		-cssCode => "", 
 		-mobilemeta => qq{<meta name="HandheldFriendly" content="true">
@@ -1168,11 +1168,11 @@ if ( $in{-titleRotatingText} and $in{-titleRotatingText} =~ /\,/ )
 	my @a;
 	@a = split(/\,/, $in{-titleRotatingText}, 3);
 
-	$setTitle = html_setTitle("$a[0]", "$a[1]", "$a[2]");
+	$setTitle = html_setTitle(ta => "$a[0]", tb => "$a[1]", tc => "$a[2]");
 }
 else
 {
-	$setTitle = html_setTitle();
+	$setTitle = html_setTitle(ta => "Text01", tb => "text02" tc => "text03");
 }
 
 # css multiple links/files 
@@ -1875,7 +1875,7 @@ A1z::HTML5::Template - Fast/easy Web Apps in Perl
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -1951,7 +1951,7 @@ version 0.17
 
 =head2 VERSION
 
-	0.17
+	0.18
 
 =head1 Installation
 
@@ -2170,7 +2170,7 @@ version 0.17
 
 	Includes the C<script> tag pair
 
-	C<$h->html_set_title( a => "Text001", b => "TExt002", c => "TeXt003" );>
+	C<$h->html_set_title( ta => "Text001", tb => "TExt002", tc => "TeXt003" );>
 
 =head2 html_humanejs_css
 
